@@ -1,12 +1,19 @@
 #!/bin/sh
 ### BEGIN INIT INFO
-# Provides:          keymap
-# Required-Start:    mountvirtfs
+# Provides:             keymap
+# Required-Start:       mountdevsubfs
 # Required-Stop:     
-# Default-Start:     S 1 2 3 4 5
-# Default-Stop:      0 6
+# Default-Start:        S
+# Default-Stop:
+# Short-Description: 	Set keymap
+# Description:		Set the Console keymap
 ### END INIT INFO
 
+# If setupcon is present, then we've been superseded by console-setup.
+if type setupcon >/dev/null 2>&1; then
+	exit 0
+fi
+
 . /lib/lsb/init-functions
 
 #
@@ -49,10 +56,14 @@ unicode_start_stop()
 	# This will be needed before loading the keymap.
 	[ -x /usr/bin/unicode_start ] || [ -x /bin/unicode_start ] ||  return
 	[ -x /usr/bin/unicode_stop ] || [ -x /bin/unicode_stop ] || return
-	[ -r /etc/environment ] || return
+
+	ENV_FILE="none"
+	[ -r /etc/environment ] && ENV_FILE="/etc/environment"
+	[ -r /etc/default/locale ] && ENV_FILE="/etc/default/locale" 
+	[ $ENV_FILE = none ] && return
 	
 	for var in LANG LC_ALL LC_CTYPE; do
-		value=$(egrep "^[^#]*${var}=" /etc/environment | tail -n1 | cut -d= -f2)
+		value=$(egrep "^[^#]*${var}=" $ENV_FILE | tail -n1 | cut -d= -f2)
 		eval $var=$value
 	done
 
@@ -69,21 +80,26 @@ if [ ! $QUIT = '1' ] ; then
   case "$1" in
       start | restart | force-reload | reload)
   
-         # First mount /proc if necessary.
-         unmount_proc="no"
-         if [ ! -x /proc/1 ]; then
-        	unmount_proc="yes"	
-          mount -n /proc
-         fi
-  
       	# Set kernel variables if required
-    	reset_kernel
+ 	reset_kernel
 
-        if [ -f /proc/sys/dev/mac_hid/keyboard_sends_linux_keycodes ] ; then
-           linux_keycodes=`cat /proc/sys/dev/mac_hid/keyboard_sends_linux_keycodes`
+        # First mount /proc if necessary...and if it is there (#392798)
+        unmount_proc="no"
+	if [ -d /proc ]; then
+        	if [ ! -x /proc/$$ ]; then
+        		unmount_proc="yes"	
+         		mount -n /proc
+        	fi
+  
+
+        	if [ -f /proc/sys/dev/mac_hid/keyboard_sends_linux_keycodes ] ; then
+        		linux_keycodes=`cat /proc/sys/dev/mac_hid/keyboard_sends_linux_keycodes`
+		else
+        		linux_keycodes=1;
+        	fi
 	else
-           linux_keycodes=1;
-        fi
+       		linux_keycodes=1;
+	fi
 
 	# load new map
 	if [ $linux_keycodes -gt 0 ] ; then 
